@@ -1,4 +1,4 @@
-__version__ = '1.1.1'
+__version__ = '1.3.1'
 
 import sys
 import json
@@ -7,7 +7,7 @@ from .symbols import *
 from .symbols import Symbol
 
 # rules
-# - keys and strings which start with $ are escaped to $$
+# - keys and strings which start with $ (or specified escape_str) are escaped to $$ (or escape_str * 2)
 # - when source is dict and diff is a dict -> patch
 # - when source is list and diff is a list patch dict -> patch
 # - else -> replacement
@@ -354,7 +354,8 @@ class JsonDiffer(object):
     class Options(object):
         pass
 
-    def __init__(self, syntax='compact', load=False, dump=False, marshal=False, loader=default_loader, dumper=default_dumper):
+    def __init__(self, syntax='compact', load=False, dump=False, marshal=False,
+                 loader=default_loader, dumper=default_dumper, escape_str='$'):
         self.options = JsonDiffer.Options()
         self.options.syntax = builtin_syntaxes.get(syntax, syntax)
         self.options.load = load
@@ -362,29 +363,31 @@ class JsonDiffer(object):
         self.options.marshal = marshal
         self.options.loader = loader
         self.options.dumper = dumper
+        self.options.escape_str = escape_str
         self._symbol_map = {
-            '$' + symbol.label: symbol
+            escape_str + symbol.label: symbol
             for symbol in _all_symbols_
         }
 
-    def _list_diff_0(self, C, X, Y, i, j):
-        if i > 0 and j > 0:
-            d, s = self._obj_diff(X[i-1], Y[j-1])
-            if s > 0 and C[i][j] == C[i-1][j-1] + s:
-                for annotation in self._list_diff_0(C, X, Y, i-1, j-1):
-                    yield annotation
-                yield (0, d, j-1, s)
-                return
-        if j > 0 and (i == 0 or C[i][j-1] >= C[i-1][j]):
-            for annotation in self._list_diff_0(C, X, Y, i, j-1):
-                yield annotation
-            yield (1, Y[j-1], j-1, 0.0)
-            return
-        if i > 0 and (j == 0 or C[i][j-1] < C[i-1][j]):
-            for annotation in self._list_diff_0(C, X, Y, i-1, j):
-                yield annotation
-            yield (-1, X[i-1], i-1, 0.0)
-            return
+    def _list_diff_0(self, C, X, Y):
+        i, j = len(X), len(Y)
+        r = []
+        while True:
+            if i > 0 and j > 0:
+                d, s = self._obj_diff(X[i-1], Y[j-1])
+                if s > 0 and C[i][j] == C[i-1][j-1] + s:
+                    r.append((0, d, j-1, s))
+                    i, j = i - 1, j - 1
+                    continue
+            if j > 0 and (i == 0 or C[i][j-1] >= C[i-1][j]):
+                r.append((1, Y[j-1], j-1, 0.0))
+                j = j - 1
+                continue
+            if i > 0 and (j == 0 or C[i][j-1] < C[i-1][j]):
+                r.append((-1, X[i-1], i-1, 0.0))
+                i = i - 1
+                continue
+            return reversed(r)
 
     def _list_diff(self, X, Y):
         # LCS
@@ -405,7 +408,8 @@ class JsonDiffer(object):
         deleted = []
         changed = {}
         tot_s = 0.0
-        for sign, value, pos, s in self._list_diff_0(C, X, Y, len(X), len(Y)):
+
+        for sign, value, pos, s in self._list_diff_0(C, X, Y):
             if sign == 1:
                 inserted.append((pos, value))
             elif sign == -1:
@@ -480,7 +484,7 @@ class JsonDiffer(object):
     def _obj_diff(self, a, b):
         if a is b:
             return self.options.syntax.emit_value_diff(a, b, 1.0), 1.0
-        if type(a) is dict and type(b) is dict:
+        if isinstance(a, dict) and isinstance(b, dict):
             return self._dict_diff(a, b)
         elif isinstance(a, tuple) and isinstance(b, tuple):
             return self._list_diff(a, b)
@@ -553,7 +557,7 @@ class JsonDiffer(object):
             sym = self._symbol_map.get(x, None)
             if sym is not None:
                 return sym
-            if x.startswith('$'):
+            if x.startswith(self.options.escape_str):
                 return x[1:]
         return x
 
@@ -573,9 +577,9 @@ class JsonDiffer(object):
 
     def _escape(self, o):
         if type(o) is Symbol:
-            return "$" + o.label
-        if isinstance(o, string_types) and o.startswith('$'):
-            return "$" + o
+            return self.options.escape_str + o.label
+        if isinstance(o, string_types) and o.startswith(self.options.escape_str):
+            return self.options.escape_str + o
         return o
 
     def marshal(self, d):
