@@ -1,12 +1,14 @@
-# this file doesn't work in Py3 - but it's only used for generating the repo front page
+# this is used for generating the repo front page
+
+from __future__ import print_function
 
 def do(cmd, comment=None):
     if comment:
-        print "# " + comment
-    print ">>> " + cmd
+        print("# " + comment)
+    print(">>> " + cmd)
     c = compile(cmd, filename="<string>", mode='single')
     eval(c, globals())
-    print
+    print()
 
 do('from jsondiff import diff')
 
@@ -26,5 +28,5 @@ do("diff({'a': 1, 'b': 2}, {'b': 3, 'c': 4}, syntax='symmetric')")
 
 do("diff({'a', 'b', 'c'}, {'a', 'c', 'd'})", "Special handling of sets")
 
-do("print diff('[\"a\", \"b\", \"c\"]', '[\"a\", \"c\", \"d\"]', load=True, dump=True)", "Load and dump JSON")
+do("print(diff('[\"a\", \"b\", \"c\"]', '[\"a\", \"c\", \"d\"]', load=True, dump=True))", "Load and dump JSON")
 
